__version__ = "0.1.16"
__git_commiter_name__ = "Guy Rozendorn"
__git_commiter_email__ = "guy@rzn.co.il"
__git_branch__ = '(Not currently on any branch)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '7f62465297bdae307b5c1420c1479ae699788ffa'
__git_head_subject__ = 'Finished release v0.1.16.'
__git_head_message__ = '# By Guy Rozendorn (2) and Arnon Yaari (1)\n* release/v0.1.16:\n  HIP-506 see previous commit\n  TRIVIAL partprobe only on the questioned device\n  empty commit after version v0.1.15'
__git_dirty_diff__ = ''